.App{text-align:center}.App-logo{height:40vmin;pointer-events:none}@media (prefers-reduced-motion:no-preference){.App-logo{animation:App-logo-spin 20s linear infinite}}.App-header{align-items:center;background-color:#282c34;color:#fff;display:flex;flex-direction:column;font-size:calc(10px + 2vmin);justify-content:center;min-height:100vh}.App-link{color:#61dafb}@keyframes App-logo-spin{0%{transform:rotate(0deg)}to{transform:rotate(1turn)}}.flowLeftFast{stroke-dasharray:5;animation:dashdrawLeftFast 5s linear infinite}@keyframes dashdrawLeftFast{to{stroke-dashoffset:200}}.flowRightFast{stroke-dasharray:5;animation:dashdrawRightFast 5s linear infinite}@keyframes dashdrawRightFast{to{stroke-dashoffset:-200}}.flowLeft{stroke-dasharray:5;animation:dashdrawLeft 5s linear infinite}@keyframes dashdrawLeft{10%,20%{stroke-dashoffset:40}30%,40%{stroke-dashoffset:80}50%,60%{stroke-dashoffset:120}70%,80%{stroke-dashoffset:160}90%,to{stroke-dashoffset:200}}.flowRight{stroke-dasharray:5;animation:dashdrawRight 5s linear infinite}@keyframes dashdrawRight{10%,20%{stroke-dashoffset:-40}30%,40%{stroke-dashoffset:-80}50%,60%{stroke-dashoffset:-120}70%,80%{stroke-dashoffset:-160}90%,to{stroke-dashoffset:-200}}@keyframes rotating-left{0%{transform:rotate(0deg)}to{transform:rotate(-1turn)}}.rotating-left{animation:rotating-left 2s linear infinite}@keyframes rotating-right{0%{transform:rotate(0deg)}to{transform:rotate(1turn)}}.rotating-right{animation:rotating-right 2s linear infinite}circle{pointer-events:auto}.shadow{filter:drop-shadow(3px 3px 2px rgba(0,0,0,.7))}.box{box-shadow:-2px 2px 5px #000;padding:0}.handle,.section_header{background-color:#3a383b;padding:5px}.no-drag{user-drag:none;-webkit-user-drag:none;-moz-user-select:none}.divgrid{background:#272227;background-attachment:local;background-image:url(data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAABkAAAAZCAYAAADE6YVjAAAAAXNSR0IArs4c6QAAAARnQU1BAACxjwv8YQUAAAAJcEhZcwAADsIAAA7CARUoSoAAAAArSURBVEhLY0hJSfnPgAaoLTYKBiEYjagRCkYjfoSC0YgfoWA04kciYGAAANbHE4SrJ1omAAAAAElFTkSuQmCC)}.divnogrid{background:#272227}.rotate0{transform:rotate(0deg)}.rotate90{transform:rotate(90deg)}.rotate180{transform:rotate(180deg)}.rotate270{transform:rotate(270deg)}.container{background-size:cover;background:#e2e2e2;background:linear-gradient(180deg,#e2e2e2 0,#dbdbdb 50%,#d1d1d1 51%,#fefefe);filter:progid:DXImageTransform.Microsoft.gradient(startColorstr="#e2e2e2",endColorstr="#fefefe",GradientType=0);padding:20px}.led-box{float:left;height:30px;margin:10px 0;width:25%}.led-box p{font-size:12px;margin:1em;text-align:center}.led-red{background-color:red;box-shadow:0 -1px 7px 1px #0003,inset 0 -1px 9px #441313,0 2px 12px #ff000080}.led-red,.led-red-off{border-radius:50%;height:24px;margin:0 auto;width:24px}.led-red-off{background-color:maroon;box-shadow:0 -1px 7px 1px #0003,inset #441313}@keyframes blinkRed{0%{background-color:red}50%{background-color:#a00;box-shadow:0 -1px 7px 1px #0003,inset 0 -1px 9px #441313,0 2px 0 #ff000080}to{background-color:red}}.led-yellow{animation:blinkYellow 1s infinite;background-color:#ff0;border-radius:50%;box-shadow:0 -1px 7px 1px #0003,inset 0 -1px 9px #808002,0 2px 12px #ff0;height:24px;margin:0 auto;width:24px}@keyframes blinkYellow{0%{background-color:#ff0}50%{background-color:#aa0;box-shadow:0 -1px 7px 1px #0003,inset 0 -1px 9px #808002,0 2px 0 #ff0}to{background-color:#ff0}}.led-green{background-color:#abff00;box-shadow:0 -1px 7px 1px #0003,inset 0 -1px 9px #304701,0 2px 12px #89ff00}.led-green,.led-green-off{border-radius:50%;height:24px;margin:0 auto;width:24px}.led-green-off{background-color:#557f00;box-shadow:0 -1px 7px 1px #0003,inset #304701}.led-blue{background-color:#24e0ff;box-shadow:0 -1px 7px 1px #0003,inset 0 -1px 9px #006,0 2px 14px #3f8cff}.led-blue,.led-blue-off{border-radius:50%;height:24px;margin:0 auto;width:24px}.led-blue-off{background-color:#006f80;box-shadow:0 -1px 7px 1px #0003,inset #006}body{-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;background-color:#272227;color:#2ff;font-family:JetBrains Mono;margin:0}body,html{touch-action:none}code{font-family:source-code-pro,Menlo,Monaco,Consolas,Courier New,monospace}.loadingbg{background:#212120;background:radial-gradient(circle,#212120 8%,#131313 93%);filter:progid:DXImageTransform.Microsoft.gradient(startColorstr="#212120",endColorstr="#131313",GradientType=1)}
/*# sourceMappingURL=main.cb9a38ea.css.map*/